@@ -25,7 +25,6 @@ import logging
 import six
 
 from vdsm.common.time import monotonic_time
-from vdsm.network import cmd
 from vdsm.network import connectivity
 from vdsm.network import errors as ne
 from vdsm.network import nmstate
@@ -113,7 +112,6 @@ def _setup_nmstate(networks, bondings, options, in_rollback):
                 config.setBonding(bond_name, bond_attrs)
         config.save()
         link_setup.setup_custom_bridge_opts(networks)
-        _setup_ovs_bridge_mappings(config.networks, networks)
         connectivity.check(options)
 
 
@@ -230,32 +228,6 @@ def _order_networks(networks):
         yield net, attr
 
 
-# FIXME This is just workaround until we have support in nmstate
-# https://bugzilla.redhat.com/1867504
-def _setup_ovs_bridge_mappings(running_networks, networks):
-    # All networks are already saved in the running_network that's why
-    # we can use the split only over running_networks
-    ovs_nets, _ = util.split_switch_type(running_networks, running_config={})
-    if networks and ovs_nets:
-        mappings = (
-            ','.join(nmstate.prepare_ovs_bridge_mappings(running_networks))
-            or '""'
-        )
-        cmds = [
-            'ovs-vsctl',
-            'set',
-            'open',
-            '.',
-            f'external-ids:ovn-bridge-mappings={mappings}',
-        ]
-        rc, out, err = cmd.exec_sync(cmds)
-        if rc:
-            raise Exception(
-                'Failed to set external mappings for OvS: '
-                f'cmd={" ".join(cmds)}, rc={rc}, out={out}, err={err}'
-            )
-
-
 def _is_changing_between_static_and_dynamic(net_attrs, rnet_attrs):
     if not rnet_attrs or net_attrs.get('remove', False):
         return False
