@@ -36,6 +36,7 @@ from vdsm import utils
 from vdsm.common import concurrent
 from vdsm.common import errors
 from vdsm.common import osutils
+from vdsm.common.panic import panic
 from vdsm.config import config
 from vdsm.storage import constants as sc
 from vdsm.storage import exception as se
@@ -217,8 +218,8 @@ class SafeLease(object):
                 raise se.AcquireLockFailure(self._sdUUID, rc, out, err)
             self.log.debug("Clustered lock acquired successfully")
 
-    def inquire(self, lease):
-        raise se.InquireNotSupportedError()
+    def inspect(self, lease):
+        raise se.InspectNotSupportedError()
 
     def getLockUtilFullPath(self):
         return os.path.join(self.lockUtilPath, self.lockCmd)
@@ -262,8 +263,20 @@ class SANLock(object):
     log = logging.getLogger("storage.SANLock")
 
     _io_timeout = config.getint('sanlock', 'io_timeout')
-    _sanlock_fd = None
-    _sanlock_lock = threading.Lock()
+
+    # Lock protecting sanlock process state.
+    _process_lock = threading.Lock()
+
+    # Global per process socket connected to sanlock. This socket is used by
+    # sanlock to detect process termination. Both acquire() and release() use
+    # this socket to communicate with sanlock, instead of opening a new
+    # connection.
+    _process_fd = None
+
+    # When starting a process, lease count is always 0, since all process
+    # leases are released when process terminates. This counter is increased
+    # when a lease is acquired, and decreased when a lease is released.
+    _lease_count = 0
 
     def __init__(self, sdUUID, idsPath, lease, *args, **kwargs):
         """
@@ -467,39 +480,55 @@ class SANLock(object):
                 "Timeout acquiring host id, cannot acquire %s (id=%s)"
                 % (lease, hostId))
 
-        with self._lock, SANLock._sanlock_lock:
+        with self._lock, SANLock._process_lock:
             while True:
-                if SANLock._sanlock_fd is None:
+                if SANLock._process_fd is None:
                     try:
-                        SANLock._sanlock_fd = sanlock.register()
+                        SANLock._process_fd = sanlock.register()
                     except sanlock.SanlockException as e:
                         raise se.AcquireLockFailure(
                             self._sdUUID, e.errno,
                             "Cannot register to sanlock", str(e))
 
-                resource_name = lease.name.encode("utf-8")
-                try:
-                    # TODO: remove once sanlock 3.8.2-4 is available on centos
-                    # and rhel.
-                    extra_args = {"lvb": lvb} if supports_lvb else {}
+                    self.log.info("Using sanlock process fd %d",
+                                  SANLock._process_fd)
 
-                    sanlock.acquire(self._lockspace_name, resource_name,
-                                    [(lease.path, lease.offset)],
-                                    slkfd=SANLock._sanlock_fd,
-                                    **extra_args)
+                # TODO: remove once sanlock 3.8.3 is available on centos.
+                extra_args = {"lvb": lvb} if supports_lvb else {}
+
+                try:
+                    sanlock.acquire(
+                        self._lockspace_name,
+                        lease.name.encode("utf-8"),
+                        [(lease.path, lease.offset)],
+                        slkfd=SANLock._process_fd,
+                        **extra_args)
                 except sanlock.SanlockException as e:
                     if e.errno != errno.EPIPE:
                         raise se.AcquireLockFailure(
                             self._sdUUID, e.errno,
                             "Cannot acquire %s" % (lease,), str(e))
-                    SANLock._sanlock_fd = None
+
+                    # If we hold leases, we just lost them, since sanlock is
+                    # releasing all process leases when the process fd is
+                    # closed. The only way to recover is to panic; child
+                    # processes run by vdsm will be killed, and vdsm will lose
+                    # the SPM role.
+                    if SANLock._lease_count > 0:
+                        panic("Sanlock process fd was closed while "
+                              "holding {} leases: {}"
+                              .format(SANLock._lease_count, e))
+
+                    self.log.warning("Sanlock process fd was closed: %s", e)
+                    SANLock._process_fd = None
                     continue
 
+                SANLock._lease_count += 1
                 break
 
         self.log.info("Successfully acquired %s for host id %s", lease, hostId)
 
-    def inquire(self, lease):
+    def inspect(self, lease):
         resource = sanlock.read_resource(
             lease.path,
             lease.offset,
@@ -534,7 +563,7 @@ class SANLock(object):
             if e.errno == errno.ENOENT:
                 # add_lockspace has not been completed yet,
                 # the inquiry has to be retried.
-                raise TemporaryFailure("inquire", lease, str(e))
+                raise TemporaryFailure("inspect", lease, str(e))
             elif e.errno == errno.EAGAIN:
                 # The host status is not available yet.
                 # Normally, we'd raise it to the caller, but this
@@ -571,15 +600,25 @@ class SANLock(object):
 
     def release(self, lease):
         self.log.info("Releasing %s", lease)
-        with self._lock:
-            resource_name = lease.name.encode("utf-8")
+
+        with self._lock, SANLock._process_lock:
             try:
-                sanlock.release(self._lockspace_name, resource_name,
-                                [(lease.path, lease.offset)],
-                                slkfd=SANLock._sanlock_fd)
+                sanlock.release(
+                    self._lockspace_name,
+                    lease.name.encode("utf-8"),
+                    [(lease.path, lease.offset)],
+                    slkfd=SANLock._process_fd)
             except sanlock.SanlockException as e:
+                # See acquire() on why we must panic.
+                if SANLock._lease_count > 0 and e.errno == errno.EPIPE:
+                    panic("Sanlock process fd was closed while "
+                          "holding {} leases: {}"
+                          .format(SANLock._lease_count, e))
+
                 raise se.ReleaseLockFailure(self._sdUUID, e)
 
+            SANLock._lease_count -= 1
+
         self.log.info("Successfully released %s", lease)
 
     def set_lvb(self, lease, info):
@@ -744,9 +783,9 @@ class LocalLock(object):
         self.log.debug("Local lock for domain %s successfully acquired "
                        "(id: %s)", self._sdUUID, hostId)
 
-    def inquire(self, lease):
+    def inspect(self, lease):
         if lease != self._lease:
-            raise MultipleLeasesNotSupported("inquire", lease)
+            raise MultipleLeasesNotSupported("inspect", lease)
         with self._globalLockMapSync:
             hostId, lockFile = self._getLease()
             return self.LVER, (hostId if lockFile else None)
